==> vite-plugin-vue-component-preview-1.0.2.tgz: package/tooling/index.js <==
"use strict";
const vue_language_core_1 = require("@volar/vue-language-core");
const plugin = (ctx) => {
    const ts = ctx.modules.typescript;
    const plugins = (0, vue_language_core_1.getDefaultVueLanguagePlugins)(ts, ctx.compilerOptions, Object.assign(Object.assign({}, ctx.vueCompilerOptions), { plugins: [] }));
    const previewBlockFiles = new Map();
    return {
        version: 1,
        getEmbeddedFileNames(fileName, sfc) {
            const previewBlock = sfc.customBlocks.find(b => b.type === 'preview' && (b.lang || 'md') === 'md');
            if (previewBlock) {
                const snapshot = ts.ScriptSnapshot.fromString(previewBlock.content);
                let vueFile = previewBlockFiles.get(fileName);
                if (!vueFile) {
                    vueFile = new vue_language_core_1.VueFile(fileName + '__VLS_preview.md', snapshot, ts, plugins);
                    previewBlockFiles.set(fileName, vueFile);
                }
                else {
                    vueFile.update(snapshot);
                }
                return vueFile.embeddedFiles
                    .map(file => file.fileName)
                    .filter(fileName => !fileName.endsWith('.html'));
            }
            return [];
        },
        resolveEmbeddedFile(fileName, sfc, embeddedFile) {
            var _a, _b;
            const vueFile = previewBlockFiles.get(fileName);
            if (vueFile) {
                const targetFile = vueFile._allEmbeddedFiles.value.find(file => file.file.fileName === embeddedFile.fileName);
                const previewBlock = sfc.customBlocks.find(b => b.type === 'preview' && (b.lang || 'md') === 'md');
                if (targetFile && previewBlock) {
                    { // watch
                        previewBlock === null || previewBlock === void 0 ? void 0 : previewBlock.content;
                    }
                    Object.assign(embeddedFile, targetFile.file);
                    const newContent = [];
                    for (const segment of targetFile.file.content) {
                        if (typeof segment === 'string') {
                            newContent.push(segment);
                        }
                        else {
                            let base = 0;
                            if (segment[1] === 'template') {
                                base = vueFile.sfc.template.startTagEnd;
                            }
                            else if (segment[1] === 'script') {
                                base = vueFile.sfc.script.startTagEnd;
                            }
                            else if (segment[1] === 'scriptSetup') {
                                base = vueFile.sfc.scriptSetup.startTagEnd;
                            }
                            else if ((_a = segment[1]) === null || _a === void 0 ? void 0 : _a.startsWith('style_')) {
                                const index = Number(segment[1].substring('style_'.length));
                                base = vueFile.sfc.styles[index].startTagEnd;
                            }
                            else if ((_b = segment[1]) === null || _b === void 0 ? void 0 : _b.startsWith('customBlock_')) {
                                const index = Number(segment[1].substring('customBlock_'.length));
                                base = vueFile.sfc.customBlocks[index].startTagEnd;
                            }
                            newContent.push([
                                segment[0],
                                previewBlock.name,
                                typeof segment[2] === 'number'
                                    ? segment[2] + base
                                    : [
                                        segment[2][0] + base,
                                        segment[2][1] + base,
                                    ],
                                segment[3],
                            ]);
                        }
                    }
                    embeddedFile.content = newContent;
                    embeddedFile.parentFileName = fileName + '.customBlock_preview_0.md';
                }
            }
        },
    };
};
module.exports = plugin;

==> vite-plugin-vue-component-preview-1.1.0.tgz: package/tooling/index.js <==
import { VueFile, getDefaultVueLanguagePlugins } from '@volar/vue-language-core';
const plugin = (ctx) => {
    const ts = ctx.modules.typescript;
    const plugins = getDefaultVueLanguagePlugins(ts, ctx.compilerOptions, { ...ctx.vueCompilerOptions, plugins: [] });
    const previewBlockFiles = new Map();
    return {
        version: 1,
        getEmbeddedFileNames(fileName, sfc) {
            const previewBlock = sfc.customBlocks.find(b => b.type === 'preview' && (b.lang || 'md') === 'md');
            if (previewBlock) {
                const snapshot = ts.ScriptSnapshot.fromString(previewBlock.content);
                let vueFile = previewBlockFiles.get(fileName);
                if (!vueFile) {
                    vueFile = new VueFile(fileName + '__VLS_preview.md', snapshot, ts, plugins);
                    previewBlockFiles.set(fileName, vueFile);
                }
                else {
                    vueFile.update(snapshot);
                }
                return vueFile.embeddedFiles.map(file => file.fileName);
            }
            return [];
        },
        resolveEmbeddedFile(fileName, sfc, embeddedFile) {
            const vueFile = previewBlockFiles.get(fileName);
            if (vueFile) {
                const targetFile = vueFile._allEmbeddedFiles.value.find(file => file.file.fileName === embeddedFile.fileName);
                const previewBlock = sfc.customBlocks.find(b => b.type === 'preview' && (b.lang || 'md') === 'md');
                if (targetFile && previewBlock) {
                    { // watch
                        previewBlock?.content;
                    }
                    Object.assign(embeddedFile, targetFile.file);
                    const newContent = [];
                    for (const segment of targetFile.file.content) {
                        if (typeof segment === 'string') {
                            newContent.push(segment);
                        }
                        else {
                            let base = 0;
                            if (segment[1] === 'template') {
                                base = vueFile.sfc.template.startTagEnd;
                            }
                            else if (segment[1] === 'script') {
                                base = vueFile.sfc.script.startTagEnd;
                            }
                            else if (segment[1] === 'scriptSetup') {
                                base = vueFile.sfc.scriptSetup.startTagEnd;
                            }
                            else if (segment[1]?.startsWith('style_')) {
                                const index = Number(segment[1].substring('style_'.length));
                                base = vueFile.sfc.styles[index].startTagEnd;
                            }
                            else if (segment[1]?.startsWith('customBlock_')) {
                                const index = Number(segment[1].substring('customBlock_'.length));
                                base = vueFile.sfc.customBlocks[index].startTagEnd;
                            }
                            newContent.push([
                                segment[0],
                                previewBlock.name,
                                typeof segment[2] === 'number'
                                    ? segment[2] + base
                                    : [
                                        segment[2][0] + base,
                                        segment[2][1] + base,
                                    ],
                                segment[3],
                            ]);
                        }
                    }
                    embeddedFile.content = newContent;
                    embeddedFile.parentFileName = fileName + '.customBlock_preview_0.md';
                }
            }
        },
    };
};
export default plugin;
